#!/usr/bin/perl -w
# produce warning if used with non-numeric values
use Test; 
BEGIN { plan tests => 15 }
BEGIN { unshift @INC, "../blib/lib" }
use POWER::lib;

# Incorrect params

$wait = {
    Records         => 0,
    DefaultCount    => 20,
    Count           => 20,
    From            => 1,
    To              => 0,
    Page            => 1,
    Prev            => undef,
    Next            => undef,
    PrevPages       => 10,
    NextPages       => 10,
    Pages           => [],
    };
$nav    = CalcNavigation();
ok(Diff($wait,$nav), 1, "without param");
$nav    = CalcNavigation({
    Records         => -5,
    });
ok(Diff($wait,$nav), 1, "-5");
$nav    = CalcNavigation({
    Records         => undef,
    DefaultCount    => undef,
    Count           => undef,
    From            => undef,
    PrevPages       => undef,
    NextPages       => undef,
    });
ok(Diff($wait,$nav), 1, "6 from 11 undef");
$nav    = CalcNavigation({
    Records         => undef,
    DefaultCount    => undef,
    Count           => undef,
    From            => undef,
    To              => undef,
    Page            => undef,
    Prev            => undef,
    Next            => undef,
    PrevPages       => undef,
    NextPages       => undef,
    Pages           => undef,
    });
ok(Diff($wait,$nav), 1, "all undef");

$wait = {
    Records         => 1,
    DefaultCount    => 1,
    Count           => 1,
    From            => 1,
    To              => 1,
    Page            => 1,
    Prev            => undef,
    Next            => undef,
    PrevPages       => 1,
    NextPages       => 1,
    Pages           => [
        { Page =>  1, From =>  1, To =>  1 },
        ],
    };
$nav    = CalcNavigation({
    Records         => 1,
    DefaultCount    => 1,
    Count           => 1,
    From            => 1,
    To              => 1,
    Page            => 1,
    Prev            => 1,
    Next            => 1,
    PrevPages       => 1,
    NextPages       => 1,
    Pages           => 1,
    });
ok(Diff($wait,$nav), 1, "all 1");

$wait = {
    Records         => 0,
    DefaultCount    => 1,
    Count           => 1,
    From            => 1,
    To              => 0,
    Page            => 1,
    Prev            => undef,
    Next            => undef,
    PrevPages       => 10,
    NextPages       => 10,
    Pages           => [],
    };
$nav    = CalcNavigation({
    Records         => -3,
    DefaultCount    => 0,
    Count           => -5,
    });
ok(Diff($wait,$nav), 1, "-3, from undef, def count 0, count -5");
$nav    = CalcNavigation({
    Records         => -3,
    DefaultCount    => -4,
    Count           => -5,
    });
ok(Diff($wait,$nav), 1, "-3, from undef, def count -4, count -5");

$wait = {
    Records         => 2,
    DefaultCount    => 1,
    Count           => 1,
    From            => 1,
    To              => 1,
    Page            => 1,
    Prev            => undef,
    Next            => 2,
    PrevPages       => 10,
    NextPages       => 10,
    Pages           => [
        { Page =>  1, From =>  1, To =>  1 },
        { Page =>  2, From =>  2, To =>  2 },
        ],
    };
$nav    = CalcNavigation({
    Records         => 2.5,
    DefaultCount    => 1.1,
    Count           => 1.9,
    });
ok(Diff($wait,$nav), 1, "-3, from undef, def count -4, count -5");

# Correct params

$wait = {
    Records         => 30,
    DefaultCount    => 20,
    Count           => 20,
    From            => 1,
    To              => 20,
    Page            => 1,
    Prev            => undef,
    Next            => 21,
    PrevPages       => 10,
    NextPages       => 10,
    Pages           => [
        { Page =>  1, From =>  1, To => 20 },
        { Page =>  2, From => 21, To => 30 },
        ],
    };
$nav    = CalcNavigation({
    Records         => 30,
    });
ok(Diff($wait,$nav), 1, "30, from undef");
$nav    = CalcNavigation({
    Records         => 30,
    From            => 0,
    });
ok(Diff($wait,$nav), 1, "30, from 0");
$nav    = CalcNavigation({
    Records         => 30,
    From            => -5,
    });
ok(Diff($wait,$nav), 1, "30, from -5");

$wait = {
    Records         => 30,
    DefaultCount    => 20,
    Count           => 20,
    From            => 21,
    To              => 30,
    Page            => 2,
    Prev            => 1,
    Next            => undef,
    PrevPages       => 10,
    NextPages       => 10,
    Pages           => [
        { Page =>  1, From =>  1, To => 20 },
        { Page =>  2, From => 21, To => 30 },
        ],
    };
$nav    = CalcNavigation({
    Records         => 30,
    From            => 28,
    });
ok(Diff($wait,$nav), 1, "30, from 28");
$nav    = CalcNavigation({
    Records         => 30,
    From            => 280,
    });
ok(Diff($wait,$nav), 1, "30, from 280");

$wait = {
    Records         => 100,
    DefaultCount    => 10,
    Count           => 10,
    From            => 51,
    To              => 60,
    Page            => 6,
    Prev            => 41,
    Next            => 61,
    PrevPages       => 0,
    NextPages       => 3,
    Pages           => [
        { Page =>  6, From => 51, To => 60 },
        { Page =>  7, From => 61, To => 70 },
        { Page =>  8, From => 71, To => 80 },
        { Page =>  9, From => 81, To => 90 },
        ],
    };
$nav    = CalcNavigation({
    Records         => 100,
    DefaultCount    => 10,
    From            => 55,
    PrevPages       => 0,
    NextPages       => 3,
    });
ok(Diff($wait,$nav), 1, "100, from 55, no prev pages, 3 next pages");

$wait = {
    Records         => 100,
    DefaultCount    => 10,
    Count           => 10,
    From            => 51,
    To              => 60,
    Page            => 6,
    Prev            => 41,
    Next            => 61,
    PrevPages       => -2,
    NextPages       => 3,
    Pages           => [
        { Page =>  8, From => 71, To => 80 },
        { Page =>  9, From => 81, To => 90 },
        ],
    };
$nav    = CalcNavigation({
    Records         => 100,
    DefaultCount    => 10,
    From            => 55,
    PrevPages       => -2,
    NextPages       => 3,
    });
ok(Diff($wait,$nav), 1, "100, from 55, -2 pages, 3 next pages");

# use Data::Dumper; print Dumper $nav;

